@@ -36,7 +36,7 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
         headers = {
             "Content-Type": "application/json"
         }
-        r = s.put(url=post_url, json=body, headers=headers)
+        r = s.post(url=post_url, json=body, headers=headers)
         r.raise_for_status()
         df = pd.read_json(r.json())
 
